@@ -5,7 +5,13 @@ from __future__ import annotations
 
 __author__: str = "Max Bachmann"
 __license__: str = "MIT"
-__version__: str = "3.1.2"
+
+import importlib.metadata
+
+try:
+    __version__: str = importlib.metadata.version(__package__ or __name__)
+except importlib.metadata.PackageNotFoundError:
+    __version__: str = "0.0.0"
 
 from rapidfuzz import distance, fuzz, process, utils
 
